# pysorteddict

Enriches Python with `SortedDict`, a sorted dictionary: a dictionary in which the keys are always in ascending order.

[Read more on the homepage.](https://tfpf.github.io/pysorteddict/)

[View the project on PyPI.](https://pypi.org/project/pysorteddict/)

[Explore the repository on GitHub.](https://github.com/tfpf/pysorteddict)

[![Hatch project](https://img.shields.io/badge/%F0%9F%A5%9A-Hatch-4051b5.svg)](https://github.com/pypa/hatch)
[![ci](https://github.com/tfpf/pysorteddict/actions/workflows/ci.yml/badge.svg)](https://github.com/tfpf/pysorteddict/actions/workflows/ci.yml)
[![pages](https://github.com/tfpf/pysorteddict/actions/workflows/pages.yml/badge.svg)](https://github.com/tfpf/pysorteddict/actions/workflows/pages.yml)
![coverage](https://img.shields.io/badge/dynamic/json?url=https%3A%2F%2Fgist.github.com%2Ftfpf%2F20ce6b322e80fe740f1ba6365fe7f110%2Fraw%2Fcoverage.json&query=%24.line_percent&suffix=%25&style=flat&logo=shieldsdotio&label=coverage&color=%2327B4A6)

<p align="center">
 <img src="https://github.com/user-attachments/assets/e9d1e78e-c0fd-4d87-93f6-e293ddef31ba" />
</p>
